import csv
from pathlib import Path

# csv
def Get_csv2List(path :str|Path) -> list:
    with open(path, 'r') as csvfile:
        reader = csv.reader(csvfile)
        data = [data for data in reader]
    return data

# text
def Get_text2list(path :str|Path, delimiter :str) -> list:
    with open(path, 'r') as f:
        return f.read().split(delimiter)

# directory
def Get_dirList(path :str|Path) -> list:
    if type(path) is str:
        path = Path(path)
    return sorted([str(f) for f in path.iterdir() if (path/f).is_dir()])

# file
def Get_fileList(path :str|Path) -> list:
    if type(path) is str:
        path = Path(path)
    return sorted([f for f in path.iterdir() if (path/f).is_file() and (not str(f).startswith("."))])

def Get_filepathList(path :str|Path):
    if type(path) is str:
        path = Path(path)
    return sorted([str((path/f).absolute()) for f in path.iterdir() if (path/f).is_file() and (not str(f).startswith("."))])

def Get_uniqueList(targetList):
    return sorted(filter(lambda a: a != '',list(set(targetList))))

def Get_keysFromValue(d, val):
    return [k for k, v in d.items() if v == val]



import itertools
import re
import time

def Conv_2dListTo1dList(l_2d):
    return list(itertools.chain.from_iterable(l_2d))

def Replace_match(sentence, targetWord, replaceWord):
    match = re.search(targetWord,sentence)
    if match:
        return sentence.replace(match.group(),replaceWord)
    else:
        return sentence

def Wait(sec):
    time.sleep(sec)




import os
import shutil
from happyset.DirFile import *

# Write
def Write_a_1dlist(filepath,writelist,delimiter):
    writelist = [str(i) for i in writelist]
    with open(filepath,'a') as f:
        f.write(delimiter.join(writelist))

def Write_a_2dlist(filepath,writelist,delimiter):
    for row in writelist:
        row = [str(i) for i in row]
        with open(filepath,'a') as f:
            f.write(delimiter.join(row)+"\n")

def Write_w_1dlist(filepath,writelist,delimiter):
    writelist = [str(i) for i in writelist]
    with open(filepath,'w') as f:
        f.write(delimiter.join(writelist))

def Write_w_2dlist(filepath,writelist,delimiter):
    Clear_file(filepath)
    for row in writelist:
        row = [str(i) for i in row]
        with open(filepath,'a') as f:
            f.write(delimiter.join(row)+"\n")



import os
import sudachipy
from sudachipy import tokenizer
from sudachipy import dictionary
import MeCab
import unidic

def Get_tokenizMecab_IPAdic(sentence):
    t = MeCab.Tagger("-r /usr/local/etc/mecabrc -d /usr/local/lib/mecab/dic/ipadic/")
    return t.parse(sentence)

def Get_tokenizMecab_unidic(sentence):
    t = MeCab.Tagger("-d "+os.path.join(unidic.__path__[0],"dicdir"))
    return t.parse(sentence)

def Get_tokenizSudachi(sentence):
    config_path = os.path.join(sudachipy.__path__[0],"resources/sudachi.json")
    tokenizer_obj = dictionary.Dictionary(config_path=config_path, dict_type='full').create()
    tokens = tokenizer_obj.tokenize(sentence,tokenizer.Tokenizer.SplitMode.C)
    output = []
    for t in tokens :
        tmp = list(t.part_of_speech())
        tmp.insert(0,t.surface())
        output.append(tmp)
    return output



import shutil
from pathlib import Path

# Clear
def Clear_dir(path :str|Path) -> None:
    shutil.rmtree(path)
    if type(path) is str:
        path = Path(path)
    path.mkdir()
    
def Clear_file(path :str|Path) -> None:
    with open(path, "r+") as f:
        f.truncate(0)

# Copy
def Copy_dir(targetPath :str|Path, createPath :str|Path) -> None:
    shutil.copytree(targetPath, createPath, dirs_exist_ok=True)

# Move
def Move_file(srcpath :str|Path, dstpath :str|Path) -> None:
    shutil.move(srcpath, dstpath)
